@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2007-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2007-2013 -- leonerd@leonerd.org.uk
 
 package IO::Async::Resolver;
 
@@ -9,9 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Function );
 
-our $VERSION = '0.53';
-
-use CPS::Future;
+our $VERSION = '0.54';
 
 use Socket 1.93 qw(
    AI_NUMERICHOST AI_PASSIVE
@@ -166,9 +164,9 @@ passed the exception thrown by the function.
 
 =back
 
-=head2 $task = $resolver->resolve( %params )
+=head2 $future = $resolver->resolve( %params )
 
-When returning a task, the C<on_resolved> and C<on_error> continuations are
+When returning a future, the C<on_resolved> and C<on_error> continuations are
 optional.
 
 =cut
@@ -194,7 +192,7 @@ sub resolve
       ref $on_resolved or croak "Expected 'on_resolved' to be a reference";
    }
    elsif( !defined wantarray ) {
-      croak "Expected 'on_resolved' or to return a Task";
+      croak "Expected 'on_resolved' or to return a Future";
    }
 
    my $on_error;
@@ -202,19 +200,19 @@ sub resolve
       ref $on_error or croak "Expected 'on_error' to be a reference";
    }
    elsif( !defined wantarray ) {
-      croak "Expected 'on_error' or to return a Task";
+      croak "Expected 'on_error' or to return a Future";
    }
 
    my $timeout = $args{timeout} || 10;
 
-   my $task = $self->call(
+   my $future = $self->call(
       args => [ $type, $timeout, @{$args{data}} ],
    );
 
-   $task->on_done( $on_resolved ) if $on_resolved;
-   $task->on_fail( $on_error    ) if $on_error;
+   $future->on_done( $on_resolved ) if $on_resolved;
+   $future->on_fail( $on_error    ) if $on_error;
 
-   return $task;
+   return $future;
 }
 
 =head2 $resolver->getaddrinfo( %args )
@@ -279,9 +277,9 @@ like an IPv4 or IPv6 string, a synchronous lookup will first be performed
 using the C<AI_NUMERICHOST> flag. If this gives an C<EAI_NONAME> error, then
 the lookup is performed asynchronously instead.
 
-=head2 $task = $resolver->getaddrinfo( %args )
+=head2 $future = $resolver->getaddrinfo( %args )
 
-When returning a task, the C<on_resolved> and C<on_error> continuations are
+When returning a future, the C<on_resolved> and C<on_error> continuations are
 optional.
 
 =cut
@@ -292,10 +290,10 @@ sub getaddrinfo
    my %args = @_;
 
    $args{on_resolved} or defined wantarray or
-      croak "Expected 'on_resolved' or to return a Task";
+      croak "Expected 'on_resolved' or to return a Future";
 
    $args{on_error} or defined wantarray or
-      croak "Expected 'on_error' or to return a Task";
+      croak "Expected 'on_error' or to return a Future";
 
    my $host    = $args{host}    || "";
    my $service = $args{service} || "";
@@ -324,19 +322,17 @@ sub getaddrinfo
        );
 
        if( !$err ) {
-          my $task = CPS::Future->new;
-          $task->on_done( $args{on_resolved} ) if $args{on_resolved};
-          $task->done( @results );
-          return $task;
+          my $future = $self->loop->new_future->done( @results );
+          $future->on_done( $args{on_resolved} ) if $args{on_resolved};
+          return $future;
        }
        elsif( $err == EAI_NONAME ) {
           # fallthrough to async case
        }
        else {
-          my $task = CPS::Future->new;
-          $task->on_fail( $args{on_error} ) if $args{on_error};
-          $task->fail( "$err\n" );
-          return $task;
+          my $future = $self->loop->new_future->fail( "$err\n" );
+          $future->on_fail( $args{on_error} ) if $args{on_error};
+          return $future;
        }
    }
 
@@ -404,9 +400,9 @@ As a specific optimsation, this method will try to perform a lookup of numeric
 values synchronously, rather than asynchronously, if both the
 C<NI_NUMERICHOST> and C<NI_NUMERICSERV> flags are given.
 
-=head2 $task = $resolver->getnameinfo( %args )
+=head2 $future = $resolver->getnameinfo( %args )
 
-When returning a task, the C<on_resolved> and C<on_error> continuations are
+When returning a future, the C<on_resolved> and C<on_error> continuations are
 optional.
 
 =cut
@@ -417,10 +413,10 @@ sub getnameinfo
    my %args = @_;
 
    $args{on_resolved} or defined wantarray or
-      croak "Expected 'on_resolved' or to return a Task";
+      croak "Expected 'on_resolved' or to return a Future";
 
    $args{on_error} or defined wantarray or
-      croak "Expected 'on_error' or to return a Task";
+      croak "Expected 'on_error' or to return a Future";
 
    my $flags = $args{flags} || 0;
 
@@ -433,21 +429,20 @@ sub getnameinfo
    if( $flags & (NI_NUMERICHOST|NI_NUMERICSERV) ) {
       # This is a numeric-only lookup that can be done synchronously
       my ( $err, $host, $service ) = _getnameinfo( $args{addr}, $flags );
-      my $task = CPS::Future->new;
 
       if( $err ) {
-         $task->on_fail( $args{on_error} ) if $args{on_error};
-         $task->fail( "$err\n" );
+         my $future = $self->loop->new_future->fail( "$err\n" );
+         $future->on_fail( $args{on_error} ) if $args{on_error};
+         return $future;
       }
       else {
-         $task->on_done( $args{on_resolved} ) if $args{on_resolved};
-         $task->done( $host, $service );
+         my $future = $self->loop->new_future->done( $host, $service );
+         $future->on_done( $args{on_resolved} ) if $args{on_resolved};
+         return $future;
       }
-
-      return $task;
    }
 
-   my $task = $self->resolve(
+   my $future = $self->resolve(
       type    => "getnameinfo",
       data    => [ $args{addr}, $flags ],
       timeout => $args{timeout},
@@ -455,10 +450,10 @@ sub getnameinfo
       done => sub { @{ $_[0] } }, # unpack the ARRAY ref
    );
 
-   $task->on_done( $args{on_resolved} ) if $args{on_resolved};
-   $task->on_fail( $args{on_error}    ) if $args{on_error};
+   $future->on_done( $args{on_resolved} ) if $args{on_resolved};
+   $future->on_fail( $args{on_error}    ) if $args{on_error};
 
-   return $task;
+   return $future;
 }
 
 =head1 FUNCTIONS
